@@ -189,6 +189,13 @@ class ShopifyBookService:
                 type=MetafieldType.single_line_text_field,
             )
         )
+        self._create_metafield_definition(
+            CreateMetafieldDefinitionInput(
+                name="Staff Comment",
+                key="staff_comment",
+                type=MetafieldType.multi_line_text_field,
+            )
+        )
 
     def _get_metafield_definitions(self) -> List[MetafieldDefinition]:
         """
